==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
var WebFilteringOperationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringOperationDescriptionMetadata, _super);
    function WebFilteringOperationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringOperationDescriptionMetadata.b = function (a) {
        if (WebFilteringOperationDescriptionMetadata.a == null) {
            WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
        }
        if (a.k(WebFilteringOperationDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringOperation");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Name", "String");
        a.item("IsUnary", "Boolean");
        a.item("IconName", "String");
        a.item("Hidden", "Boolean");
    };
    WebFilteringOperationDescriptionMetadata.d = function (a) {
        WebFilteringOperationDescriptionMetadata.b(a);
        a.ad("WebFilteringOperation", function () { return new WebFilteringOperationDescription(); });
        a.ac("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.$t = markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
}(Base));
export { WebFilteringOperationDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
var WebFilteringOperationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringOperationDescriptionMetadata, _super);
    function WebFilteringOperationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringOperationDescriptionMetadata.b = function (a) {
        if (WebFilteringOperationDescriptionMetadata.a == null) {
            WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
        }
        if (a.k(WebFilteringOperationDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringOperation");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("__isTSPlainInterface", "Boolean");
        a.item("Name", "String");
        a.item("IsUnary", "Boolean");
        a.item("IconName", "String");
        a.item("Hidden", "Boolean");
        a.item("LogicRef", "(w:Logic,wf:Logic)MethodRef");
    };
    WebFilteringOperationDescriptionMetadata.d = function (a) {
        WebFilteringOperationDescriptionMetadata.b(a);
        a.ae("WebFilteringOperation", function () { return new WebFilteringOperationDescription(); });
        a.ad("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.$t = markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
}(Base));
export { WebFilteringOperationDescriptionMetadata };
